@@ -18,18 +18,18 @@
  */
 import React from 'react';
 import { shallow } from 'enzyme';
-import { SuperChart } from '@superset-ui/chart';
+import { SuperChart } from '@superset-ui/core';
 
 import ChartRenderer from 'src/chart/ChartRenderer';
 
 describe('ChartRenderer', () => {
   it('should render SuperChart', () => {
     const wrapper = shallow(<ChartRenderer refreshOverlayVisible={false} />);
-    expect(wrapper.find(SuperChart)).toHaveLength(1);
+    expect(wrapper.find(SuperChart)).toExist();
   });
 
   it('should not render SuperChart when refreshOverlayVisible is true', () => {
     const wrapper = shallow(<ChartRenderer refreshOverlayVisible />);
-    expect(wrapper.find(SuperChart)).toHaveLength(0);
+    expect(wrapper.find(SuperChart)).not.toExist();
   });
 });
