@@ -74,20 +74,20 @@ describe('Chart', () => {
 
   it('should render a SliceHeader', () => {
     const wrapper = setup();
-    expect(wrapper.find(SliceHeader)).toHaveLength(1);
+    expect(wrapper.find(SliceHeader)).toExist();
   });
 
   it('should render a ChartContainer', () => {
     const wrapper = setup();
-    expect(wrapper.find(ChartContainer)).toHaveLength(1);
+    expect(wrapper.find(ChartContainer)).toExist();
   });
 
   it('should render a description if it has one and isExpanded=true', () => {
     const wrapper = setup();
-    expect(wrapper.find('.slice_description')).toHaveLength(0);
+    expect(wrapper.find('.slice_description')).not.toExist();
 
     wrapper.setProps({ ...props, isExpanded: true });
-    expect(wrapper.find('.slice_description')).toHaveLength(1);
+    expect(wrapper.find('.slice_description')).toExist();
   });
 
   it('should call refreshChart when SliceHeader calls forceRefresh', () => {
