@@ -16,7 +16,7 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-import { t } from '@superset-ui/translation';
+import { t } from '@superset-ui/core';
 
 import getInitialState from './getInitialState';
 import * as actions from '../actions/sqlLab';
@@ -375,7 +375,7 @@ export default function sqlLabReducer(state = {}, action) {
     },
     [actions.MIGRATE_QUERY_EDITOR]() {
       // remove migrated query editor from localStorage
-      const sqlLab = JSON.parse(localStorage.getItem('redux')).sqlLab;
+      const { sqlLab } = JSON.parse(localStorage.getItem('redux'));
       sqlLab.queryEditors = sqlLab.queryEditors.filter(
         qe => qe.id !== action.oldQueryEditor.id,
       );
@@ -390,7 +390,7 @@ export default function sqlLabReducer(state = {}, action) {
     },
     [actions.MIGRATE_TABLE]() {
       // remove migrated table from localStorage
-      const sqlLab = JSON.parse(localStorage.getItem('redux')).sqlLab;
+      const { sqlLab } = JSON.parse(localStorage.getItem('redux'));
       sqlLab.tables = sqlLab.tables.filter(
         table => table.id !== action.oldTable.id,
       );
@@ -405,7 +405,7 @@ export default function sqlLabReducer(state = {}, action) {
     },
     [actions.MIGRATE_TAB_HISTORY]() {
       // remove migrated tab from localStorage tabHistory
-      const sqlLab = JSON.parse(localStorage.getItem('redux')).sqlLab;
+      const { sqlLab } = JSON.parse(localStorage.getItem('redux'));
       sqlLab.tabHistory = sqlLab.tabHistory.filter(
         tabId => tabId !== action.oldId,
       );
@@ -492,9 +492,8 @@ export default function sqlLabReducer(state = {}, action) {
       let newQueries = { ...state.queries };
       // Fetch the updates to the queries present in the store.
       let change = false;
-      let queriesLastUpdate = state.queriesLastUpdate;
-      for (const id in action.alteredQueries) {
-        const changedQuery = action.alteredQueries[id];
+      let { queriesLastUpdate } = state;
+      Object.entries(action.alteredQueries).forEach(([id, changedQuery]) => {
         if (
           !state.queries.hasOwnProperty(id) ||
           (state.queries[id].state !== 'stopped' &&
@@ -506,7 +505,7 @@ export default function sqlLabReducer(state = {}, action) {
           newQueries[id] = { ...state.queries[id], ...changedQuery };
           change = true;
         }
-      }
+      });
       if (!change) {
         newQueries = state.queries;
       }
