@@ -19,20 +19,24 @@
 import React from 'react';
 import PropTypes from 'prop-types';
 import { CompactPicker } from 'react-color';
-import { Button } from 'react-bootstrap';
+import Button from 'src/components/Button';
 import mathjs from 'mathjs';
-import { t } from '@superset-ui/translation';
-import { SupersetClient } from '@superset-ui/connection';
-import { getCategoricalSchemeRegistry } from '@superset-ui/color';
-import { getChartMetadataRegistry } from '@superset-ui/chart';
-import { validateNonEmpty } from '@superset-ui/validator';
+import {
+  t,
+  SupersetClient,
+  getCategoricalSchemeRegistry,
+  getChartMetadataRegistry,
+  ThemeProvider,
+  validateNonEmpty,
+} from '@superset-ui/core';
 
 import SelectControl from './SelectControl';
 import TextControl from './TextControl';
 import CheckboxControl from './CheckboxControl';
 
-import ANNOTATION_TYPES, {
+import {
   ANNOTATION_SOURCE_TYPES,
+  ANNOTATION_TYPES,
   ANNOTATION_TYPES_METADATA,
   DEFAULT_ANNOTATION_TYPE,
   requiresQuery,
@@ -63,6 +67,7 @@ const propTypes = {
   timeColumn: PropTypes.string,
   intervalEndColumn: PropTypes.string,
   vizType: PropTypes.string,
+  theme: PropTypes.object,
 
   error: PropTypes.string,
   colorScheme: PropTypes.string,
@@ -328,7 +333,7 @@ export default class AnnotationLayer extends React.PureComponent {
       annotation.color =
         annotation.color === AUTOMATIC_COLOR ? null : annotation.color;
       this.props.addAnnotationLayer(annotation);
-      this.setState({ isNew: false, oldName: this.state.name });
+      this.setState(prevState => ({ isNew: false, oldName: prevState.name }));
     }
   }
 
@@ -423,7 +428,7 @@ export default class AnnotationLayer extends React.PureComponent {
       intervalEndColumn,
       descriptionColumns,
     } = this.state;
-    const slice = (valueOptions.find(x => x.value === value) || {}).slice;
+    const { slice } = valueOptions.find(x => x.value === value) || {};
     if (sourceType !== ANNOTATION_SOURCE_TYPES.NATIVE && slice) {
       const columns = (slice.data.groupby || [])
         .concat(slice.data.all_columns || [])
@@ -450,7 +455,7 @@ export default class AnnotationLayer extends React.PureComponent {
                     ? 'Interval Start column'
                     : 'Event Time Column'
                 }
-                description={'This column must contain date/time information.'}
+                description="This column must contain date/time information."
                 validationErrors={!timeColumn ? ['Mandatory'] : []}
                 clearable={false}
                 options={timeColumnOptions}
@@ -463,7 +468,7 @@ export default class AnnotationLayer extends React.PureComponent {
                 hovered
                 name="annotation-layer-intervalEnd"
                 label="Interval End column"
-                description={'This column must contain date/time information.'}
+                description="This column must contain date/time information."
                 validationErrors={!intervalEndColumn ? ['Mandatory'] : []}
                 options={columns}
                 value={intervalEndColumn}
@@ -474,7 +479,7 @@ export default class AnnotationLayer extends React.PureComponent {
               hovered
               name="annotation-layer-title"
               label="Title Column"
-              description={'Pick a title for you annotation.'}
+              description="Pick a title for you annotation."
               options={[{ value: '', label: 'None' }].concat(columns)}
               value={titleColumn}
               onChange={v => this.setState({ titleColumn: v })}
@@ -619,8 +624,8 @@ export default class AnnotationLayer extends React.PureComponent {
             />
             <Button
               style={{ marginTop: '0.5rem', marginBottom: '0.5rem' }}
-              bsStyle={color === AUTOMATIC_COLOR ? 'success' : 'default'}
-              bsSize="xsmall"
+              buttonStyle={color === AUTOMATIC_COLOR ? 'success' : 'default'}
+              buttonSize="xsmall"
               onClick={() => this.setState({ color: AUTOMATIC_COLOR })}
             >
               Automatic Color
@@ -639,7 +644,7 @@ export default class AnnotationLayer extends React.PureComponent {
             hovered
             name="annotation-layer-show-markers"
             label="Show Markers"
-            description={'Shows or hides markers for the time series'}
+            description="Shows or hides markers for the time series"
             value={showMarkers}
             onChange={v => this.setState({ showMarkers: v })}
           />
@@ -649,7 +654,7 @@ export default class AnnotationLayer extends React.PureComponent {
             hovered
             name="annotation-layer-hide-line"
             label="Hide Line"
-            description={'Hides the Line for the time series'}
+            description="Hides the Line for the time series"
             value={hideLine}
             onChange={v => this.setState({ hideLine: v })}
           />
@@ -661,7 +666,7 @@ export default class AnnotationLayer extends React.PureComponent {
   render() {
     const { isNew, name, annotationType, sourceType, show } = this.state;
     const isValid = this.isValidForm();
-
+    const { theme } = this.props;
     const metadata = getChartMetadataRegistry().get(this.props.vizType);
     const supportedAnnotationTypes = metadata
       ? metadata.supportedAnnotationTypes.map(
@@ -671,7 +676,7 @@ export default class AnnotationLayer extends React.PureComponent {
     const supportedSourceTypes = this.getSupportedSourceTypes(annotationType);
 
     return (
-      <div>
+      <ThemeProvider theme={theme}>
         {this.props.error && (
           <span style={{ color: 'red' }}>ERROR: {this.props.error}</span>
         )}
@@ -724,12 +729,12 @@ export default class AnnotationLayer extends React.PureComponent {
           {this.renderDisplayConfiguration()}
         </div>
         <div style={{ display: 'flex', justifyContent: 'space-between' }}>
-          <Button bsSize="sm" onClick={this.deleteAnnotation}>
+          <Button buttonSize="sm" onClick={this.deleteAnnotation}>
             {!isNew ? t('Remove') : t('Cancel')}
           </Button>
           <div>
             <Button
-              bsSize="sm"
+              buttonSize="sm"
               disabled={!isValid}
               onClick={this.applyAnnotation}
             >
@@ -737,7 +742,7 @@ export default class AnnotationLayer extends React.PureComponent {
             </Button>
 
             <Button
-              bsSize="sm"
+              buttonSize="sm"
               disabled={!isValid}
               onClick={this.submitAnnotation}
             >
@@ -745,7 +750,7 @@ export default class AnnotationLayer extends React.PureComponent {
             </Button>
           </div>
         </div>
-      </div>
+      </ThemeProvider>
     );
   }
 }
