@@ -41,10 +41,9 @@ from superset.charts.commands.exceptions import (
     ChartUpdateFailedError,
 )
 from superset.charts.commands.update import UpdateChartCommand
-from superset.charts.dao import ChartDAO
-from superset.charts.filters import ChartFilter, ChartNameOrDescriptionFilter
+from superset.charts.filters import ChartAllTextFilter, ChartFavoriteFilter, ChartFilter
 from superset.charts.schemas import (
-    CHART_DATA_SCHEMAS,
+    CHART_SCHEMAS,
     ChartDataQueryContextSchema,
     ChartPostSchema,
     ChartPutSchema,
@@ -84,64 +83,77 @@ class ChartRestApi(BaseSupersetModelRestApi):
         "bulk_delete",  # not using RouteMethod since locally defined
         "data",
         "viz_types",
-        "datasources",
     }
     class_permission_name = "SliceModelView"
     show_columns = [
-        "slice_name",
-        "description",
-        "owners.id",
-        "owners.username",
-        "owners.first_name",
-        "owners.last_name",
-        "dashboards.id",
-        "dashboards.dashboard_title",
-        "viz_type",
-        "params",
         "cache_timeout",
+        "dashboards.dashboard_title",
+        "dashboards.id",
+        "description",
+        "owners.first_name",
+        "owners.id",
+        "owners.last_name",
+        "owners.username",
+        "params",
+        "slice_name",
+        "viz_type",
     ]
     show_select_columns = show_columns + ["table.id"]
     list_columns = [
-        "id",
-        "slice_name",
-        "url",
-        "description",
-        "changed_by_name",
-        "changed_by_url",
+        "cache_timeout",
         "changed_by.first_name",
         "changed_by.last_name",
-        "changed_on_utc",
+        "changed_by_name",
+        "changed_by_url",
         "changed_on_delta_humanized",
+        "changed_on_utc",
+        "created_by.first_name",
+        "created_by.id",
+        "created_by.last_name",
         "datasource_id",
-        "datasource_type",
         "datasource_name_text",
+        "datasource_type",
         "datasource_url",
+        "description",
+        "id",
+        "owners.first_name",
+        "owners.id",
+        "owners.last_name",
+        "owners.username",
+        "params",
+        "slice_name",
         "table.default_endpoint",
         "table.table_name",
+        "thumbnail_url",
+        "url",
         "viz_type",
-        "params",
-        "cache_timeout",
     ]
-    list_select_columns = list_columns + ["changed_on", "changed_by_fk"]
+    list_select_columns = list_columns + ["changed_by_fk", "changed_on"]
     order_columns = [
-        "slice_name",
-        "viz_type",
-        "datasource_name",
         "changed_by.first_name",
         "changed_on_delta_humanized",
-    ]
-    search_columns = (
-        "slice_name",
-        "description",
-        "viz_type",
-        "datasource_name",
         "datasource_id",
+        "datasource_name",
+        "slice_name",
+        "viz_type",
+    ]
+    search_columns = [
+        "created_by",
+        "datasource_id",
+        "datasource_name",
         "datasource_type",
+        "description",
+        "id",
         "owners",
-    )
+        "slice_name",
+        "viz_type",
+    ]
     base_order = ("changed_on", "desc")
     base_filters = [["id", ChartFilter, lambda: []]]
-    search_filters = {"slice_name": [ChartNameOrDescriptionFilter]}
+    search_filters = {
+        "id": [ChartFavoriteFilter],
+        "slice_name": [ChartAllTextFilter],
+    }
 
     # Will just affect _info endpoint
     edit_columns = ["slice_name"]
@@ -152,7 +164,12 @@ class ChartRestApi(BaseSupersetModelRestApi):
 
     openapi_spec_tag = "Charts"
     """ Override the name set for this collection of endpoints """
-    openapi_spec_component_schemas = CHART_DATA_SCHEMAS
+    openapi_spec_component_schemas = CHART_SCHEMAS
+
+    apispec_parameter_schemas = {
+        "screenshot_query_schema": screenshot_query_schema,
+        "get_delete_ids_schema": get_delete_ids_schema,
+    }
     """ Add extra schemas to the OpenAPI components schema section """
     openapi_spec_methods = openapi_spec_methods_override
     """ Overrides GET methods OpenApi descriptions """
@@ -163,10 +180,11 @@ class ChartRestApi(BaseSupersetModelRestApi):
     }
 
     related_field_filters = {
-        "owners": RelatedFieldFilter("first_name", FilterRelatedOwners)
+        "owners": RelatedFieldFilter("first_name", FilterRelatedOwners),
+        "created_by": RelatedFieldFilter("first_name", FilterRelatedOwners),
     }
 
-    allowed_rel_fields = {"owners"}
+    allowed_rel_fields = {"owners", "created_by"}
 
     def __init__(self) -> None:
         if is_feature_enabled("THUMBNAILS"):
@@ -237,9 +255,7 @@ class ChartRestApi(BaseSupersetModelRestApi):
     @protect()
     @safe
     @statsd_metrics
-    def put(  # pylint: disable=too-many-return-statements, arguments-differ
-        self, pk: int
-    ) -> Response:
+    def put(self, pk: int) -> Response:
         """Changes a Chart
         ---
         put:
@@ -282,6 +298,7 @@ class ChartRestApi(BaseSupersetModelRestApi):
             500:
               $ref: '#/components/responses/500'
         """
+
         if not request.is_json:
             return self.response_400(message="Request is not JSON")
         try:
@@ -289,26 +306,29 @@ class ChartRestApi(BaseSupersetModelRestApi):
         # This validates custom Schema with custom validations
         except ValidationError as error:
             return self.response_400(message=error.messages)
+
         try:
             changed_model = UpdateChartCommand(g.user, pk, item).run()
-            return self.response(200, id=changed_model.id, result=item)
+            response = self.response(200, id=changed_model.id, result=item)
         except ChartNotFoundError:
-            return self.response_404()
+            response = self.response_404()
         except ChartForbiddenError:
-            return self.response_403()
+            response = self.response_403()
         except ChartInvalidError as ex:
-            return self.response_422(message=ex.normalized_messages())
+            response = self.response_422(message=ex.normalized_messages())
         except ChartUpdateFailedError as ex:
             logger.error(
                 "Error updating model %s: %s", self.__class__.__name__, str(ex)
             )
-            return self.response_422(message=str(ex))
+            response = self.response_422(message=str(ex))
+
+        return response
 
     @expose("/<pk>", methods=["DELETE"])
     @protect()
     @safe
     @statsd_metrics
-    def delete(self, pk: int) -> Response:  # pylint: disable=arguments-differ
+    def delete(self, pk: int) -> Response:
         """Deletes a Chart
         ---
         delete:
@@ -358,9 +378,7 @@ class ChartRestApi(BaseSupersetModelRestApi):
     @safe
     @statsd_metrics
     @rison(get_delete_ids_schema)
-    def bulk_delete(
-        self, **kwargs: Any
-    ) -> Response:  # pylint: disable=arguments-differ
+    def bulk_delete(self, **kwargs: Any) -> Response:
         """Delete bulk Charts
         ---
         delete:
@@ -372,9 +390,7 @@ class ChartRestApi(BaseSupersetModelRestApi):
             content:
               application/json:
                 schema:
-                  type: array
-                  items:
-                    type: integer
+                  $ref: '#/components/schemas/get_delete_ids_schema'
           responses:
             200:
               description: Charts bulk delete
@@ -417,7 +433,7 @@ class ChartRestApi(BaseSupersetModelRestApi):
     @protect()
     @safe
     @statsd_metrics
-    def data(self) -> Response:  # pylint: disable=too-many-return-statements
+    def data(self) -> Response:
         """
         Takes a query context constructed in the client and returns payload
         data response for the given query.
@@ -471,10 +487,15 @@ class ChartRestApi(BaseSupersetModelRestApi):
             if query.get("error"):
                 return self.response_400(message=f"Error: {query['error']}")
         result_format = query_context.result_format
+
+        response = self.response_400(
+            message=f"Unsupported result_format: {result_format}"
+        )
+
         if result_format == ChartDataResultFormat.CSV:
             # return the first result
             result = payload[0]["data"]
-            return CsvResponse(
+            response = CsvResponse(
                 result,
                 status=200,
                 headers=generate_download_headers("csv"),
@@ -487,9 +508,9 @@ class ChartRestApi(BaseSupersetModelRestApi):
             )
             resp = make_response(response_data, 200)
             resp.headers["Content-Type"] = "application/json; charset=utf-8"
-            return resp
+            response = resp
 
-        return self.response_400(message=f"Unsupported result_format: {result_format}")
+        return response
 
     @expose("/<pk>/cache_screenshot/", methods=["GET"])
     @protect()
@@ -497,33 +518,28 @@ class ChartRestApi(BaseSupersetModelRestApi):
     @safe
     @statsd_metrics
     def cache_screenshot(self, pk: int, **kwargs: Dict[str, bool]) -> WerkzeugResponse:
-        """Get Chart screenshot
+        """
         ---
         get:
-          description: Compute or get already computed screenshot from cache.
+          description: Compute and cache a screenshot.
           parameters:
           - in: path
             schema:
               type: integer
             name: pk
-          - in: path
-            schema:
-              type: string
-            name: sha
+          - in: query
+            name: q
+            content:
+              application/json:
+                schema:
+                  $ref: '#/components/schemas/screenshot_query_schema'
           responses:
             200:
-              description: Chart thumbnail image
+              description: Chart async result
               content:
                 application/json:
                   schema:
-                    type: object
-                    properties:
-                      cache_key:
-                        type: string
-                      chart_url:
-                        type: string
-                      image_url:
-                        type: string
+                    $ref: "#/components/schemas/ChartCacheScreenshotResponseSchema"
             302:
               description: Redirects to the current digest
             400:
@@ -563,7 +579,7 @@ class ChartRestApi(BaseSupersetModelRestApi):
             }
             cache_chart_thumbnail.delay(**kwargs)
             return self.response(
-                202, cache_key=cache_key, chart_url=chart_url, image_url=image_url,
+                202, cache_key=cache_key, chart_url=chart_url, image_url=image_url
             )
 
         return trigger_celery()
@@ -612,8 +628,6 @@ class ChartRestApi(BaseSupersetModelRestApi):
         if not chart:
             return self.response_404()
 
-        # TODO make sure the user has access to the chart
-
         # fetch the chart screenshot using the current user and cache if set
         img = ChartScreenshot.get_from_cache_key(thumbnail_cache, digest)
         if img:
@@ -647,7 +661,7 @@ class ChartRestApi(BaseSupersetModelRestApi):
           responses:
             200:
               description: Chart thumbnail image
-              /content:
+              content:
                image/*:
                  schema:
                    type: string
@@ -695,57 +709,3 @@ class ChartRestApi(BaseSupersetModelRestApi):
         return Response(
             FileWrapper(screenshot), mimetype="image/png", direct_passthrough=True
         )
-
-    @expose("/datasources", methods=["GET"])
-    @protect()
-    @safe
-    def datasources(self) -> Response:
-        """Get available datasources
-        ---
-        get:
-          description: Get available datasources.
-          responses:
-            200:
-              description: charts unique datasource data
-              content:
-                application/json:
-                  schema:
-                    type: object
-                    properties:
-                      count:
-                        type: integer
-                      result:
-                        type: object
-                        properties:
-                          label:
-                            type: string
-                          value:
-                            type: object
-                            properties:
-                              database_id:
-                                type: integer
-                              database_type:
-                                type: string
-            400:
-              $ref: '#/components/responses/400'
-            401:
-              $ref: '#/components/responses/401'
-            404:
-              $ref: '#/components/responses/404'
-            422:
-              $ref: '#/components/responses/422'
-            500:
-              $ref: '#/components/responses/500'
-        """
-        datasources = ChartDAO.fetch_all_datasources()
-        if not datasources:
-            return self.response(200, count=0, result=[])
-
-        result = [
-            {
-                "label": str(ds),
-                "value": {"datasource_id": ds.id, "datasource_type": ds.type},
-            }
-            for ds in datasources
-        ]
-        return self.response(200, count=len(result), result=result)
