@@ -27,7 +27,6 @@ from superset.db_engine_specs.base import BaseEngineSpec
 from superset.utils import core as utils
 
 if TYPE_CHECKING:
-    # pylint: disable=unused-import
     from superset.models.core import Database  # pragma: no cover
 
 
@@ -37,6 +36,7 @@ class BigQueryEngineSpec(BaseEngineSpec):
     As contributed by @mxmzdlv on issue #945"""
 
     engine = "bigquery"
+    engine_name = "Google BigQuery"
     max_column_name_length = 128
 
     """
