@@ -41,7 +41,7 @@ from superset.utils import core as utils
 
 if TYPE_CHECKING:
     # prevent circular imports
-    from superset.models.core import Database  # pylint: disable=unused-import
+    from superset.models.core import Database
 
 QueryStatus = utils.QueryStatus
 config = app.config
@@ -51,10 +51,33 @@ tracking_url_trans = conf.get("TRACKING_URL_TRANSFORMER")
 hive_poll_interval = conf.get("HIVE_POLL_INTERVAL")
 
 
+def upload_to_s3(filename: str, upload_prefix: str, table: Table) -> str:
+    # Optional dependency
+    import boto3  # pylint: disable=import-error
+
+    bucket_path = config["CSV_TO_HIVE_UPLOAD_S3_BUCKET"]
+
+    if not bucket_path:
+        logger.info("No upload bucket specified")
+        raise Exception(
+            "No upload bucket specified. You can specify one in the config file."
+        )
+
+    s3 = boto3.client("s3")
+    location = os.path.join("s3a://", bucket_path, upload_prefix, table.table)
+    s3.upload_file(
+        filename,
+        bucket_path,
+        os.path.join(upload_prefix, table.table, os.path.basename(filename)),
+    )
+    return location
+
+
 class HiveEngineSpec(PrestoEngineSpec):
     """Reuses PrestoEngineSpec functionality."""
 
     engine = "hive"
+    engine_name = "Apache Hive"
     max_column_name_length = 767
     # pylint: disable=line-too-long
     _time_grain_expressions = {
@@ -88,14 +111,15 @@ class HiveEngineSpec(PrestoEngineSpec):
 
     @classmethod
     def patch(cls) -> None:
-        from pyhive import hive  # pylint: disable=no-name-in-module
-        from superset.db_engines import hive as patched_hive
+        from pyhive import hive
         from TCLIService import (
             constants as patched_constants,
-            ttypes as patched_ttypes,
             TCLIService as patched_TCLIService,
+            ttypes as patched_ttypes,
         )
 
+        from superset.db_engines import hive as patched_hive
+
         hive.TCLIService = patched_TCLIService
         hive.constants = patched_constants
         hive.ttypes = patched_ttypes
@@ -171,7 +195,6 @@ class HiveEngineSpec(PrestoEngineSpec):
         df_to_sql_kwargs: Dict[str, Any],
     ) -> None:
         """Uploads a csv file and creates a superset datasource in Hive."""
-
         if_exists = df_to_sql_kwargs["if_exists"]
         if if_exists == "append":
             raise SupersetException("Append operation not currently supported")
@@ -186,14 +209,6 @@ class HiveEngineSpec(PrestoEngineSpec):
             }
             return tableschema_to_hive_types.get(col_type, "STRING")
 
-        bucket_path = config["CSV_TO_HIVE_UPLOAD_S3_BUCKET"]
-
-        if not bucket_path:
-            logger.info("No upload bucket specified")
-            raise Exception(
-                "No upload bucket specified. You can specify one in the config file."
-            )
-
         upload_prefix = config["CSV_TO_HIVE_UPLOAD_DIRECTORY_FUNC"](
             database, g.user, table.schema
         )
@@ -214,30 +229,23 @@ class HiveEngineSpec(PrestoEngineSpec):
         schema_definition = ", ".join(column_name_and_type)
 
         # ensure table doesn't already exist
-        if (
-            if_exists == "fail"
-            and not database.get_df(
-                f"SHOW TABLES IN {table.schema} LIKE '{table.table}'"
-            ).empty
-        ):
-            raise SupersetException("Table already exists")
+        if if_exists == "fail":
+            if table.schema:
+                table_exists = not database.get_df(
+                    f"SHOW TABLES IN {table.schema} LIKE '{table.table}'"
+                ).empty
+            else:
+                table_exists = not database.get_df(
+                    f"SHOW TABLES LIKE '{table.table}'"
+                ).empty
+            if table_exists:
+                raise SupersetException("Table already exists")
 
         engine = cls.get_engine(database)
 
         if if_exists == "replace":
             engine.execute(f"DROP TABLE IF EXISTS {str(table)}")
-
-        # Optional dependency
-        import boto3  # pylint: disable=import-error
-
-        s3 = boto3.client("s3")
-        location = os.path.join("s3a://", bucket_path, upload_prefix, table.table)
-        s3.upload_file(
-            filename,
-            bucket_path,
-            os.path.join(upload_prefix, table.table, os.path.basename(filename)),
-        )
-
+        location = upload_to_s3(filename, upload_prefix, table)
         sql, params = cls.get_create_table_stmt(
             table,
             schema_definition,
@@ -255,7 +263,8 @@ class HiveEngineSpec(PrestoEngineSpec):
         if tt == utils.TemporalType.DATE:
             return f"CAST('{dttm.date().isoformat()}' AS DATE)"
         if tt == utils.TemporalType.TIMESTAMP:
-            return f"""CAST('{dttm.isoformat(sep=" ", timespec="microseconds")}' AS TIMESTAMP)"""  # pylint: disable=line-too-long
+            return f"""CAST('{dttm
+                .isoformat(sep=" ", timespec="microseconds")}' AS TIMESTAMP)"""
         return None
 
     @classmethod
@@ -317,7 +326,7 @@ class HiveEngineSpec(PrestoEngineSpec):
         cls, cursor: Any, query: Query, session: Session
     ) -> None:
         """Updates progress information"""
-        from pyhive import hive  # pylint: disable=no-name-in-module
+        from pyhive import hive
 
         unfinished_states = (
             hive.ttypes.TOperationState.INITIALIZED_STATE,
