@@ -14,7 +14,11 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-from . import core  # noqa
-from . import sql_lab  # noqa
-from . import user_attributes  # noqa
-from . import schedules  # noqa
+from . import (
+    alerts,
+    core,
+    datasource_access_request,
+    schedules,
+    sql_lab,
+    user_attributes,
+)
